@@ -1,7 +1,7 @@
 # ---------------------------------------------------------------------------------------------------------
 #  Copyright 2003-2010 by Alex Peeters [alex.peeters@citap.be]
 # ---------------------------------------------------------------------------------------------------------
-# 2010/03/10, v3.001.003, snmptt-3.001.003-v5.0.x.sql
+# 2010/mm/dd, v3.002.001, snmptt-3.002.001-v5.0.x.sql
 # ---------------------------------------------------------------------------------------------------------
 
 create database if not exists `snmptt`;
